package com.sun.xml.tree;

import java.io.IOException;
import java.io.Writer;
import org.w3c.dom.DocumentType;
import org.w3c.dom.Element;
import org.w3c.dom.NamedNodeMap;
import org.w3c.dom.Node;

final class Doctype extends NodeBase implements DocumentType {
   private String name;
   private Nodemap entities;
   private Nodemap notations;
   private String publicId;
   private String systemId;
   private String internalSubset;

   Doctype(String var1) {
      this.name = var1;
      this.entities = new Nodemap();
      this.notations = new Nodemap();
   }

   Doctype(String var1, String var2, String var3) {
      this.publicId = var1;
      this.systemId = var2;
      this.internalSubset = var3;
   }

   void addEntityNode(String var1, String var2) {
      if (!"lt".equals(var1) && !"gt".equals(var1) && !"apos".equals(var1) && !"quot".equals(var1) && !"amp".equals(var1)) {
         EntityNode var3 = new EntityNode(var1, var2);
         ((NodeBase)var3).setOwnerDocument((XmlDocument)((NodeBase)this).getOwnerDocument());
         this.entities.setNamedItem(var3);
      }
   }

   void addEntityNode(String var1, String var2, String var3, String var4) {
      EntityNode var5 = new EntityNode(var1, var2, var3, var4);
      ((NodeBase)var5).setOwnerDocument((XmlDocument)((NodeBase)this).getOwnerDocument());
      this.entities.setNamedItem(var5);
   }

   void addNotation(String var1, String var2, String var3) {
      NotationNode var4 = new NotationNode(var1, var2, var3);
      ((NodeBase)var4).setOwnerDocument((XmlDocument)((NodeBase)this).getOwnerDocument());
      this.notations.setNamedItem(var4);
   }

   /** @deprecated */
   public Node cloneNode(boolean var1) {
      throw new RuntimeException(((NodeBase)this).getMessage("DT-000"));
   }

   public NamedNodeMap getEntities() {
      return this.entities;
   }

   public String getName() {
      return this.name;
   }

   public String getNodeName() {
      return this.name;
   }

   public short getNodeType() {
      return 10;
   }

   public NamedNodeMap getNotations() {
      return this.notations;
   }

   void setOwnerDocument(XmlDocument var1) {
      super.setOwnerDocument(var1);
      if (this.entities != null) {
         for(int var2 = 0; this.entities.item(var2) != null; ++var2) {
            ((NodeBase)this.entities.item(var2)).setOwnerDocument(var1);
         }
      }

      if (this.notations != null) {
         for(int var3 = 0; this.notations.item(var3) != null; ++var3) {
            ((NodeBase)this.notations.item(var3)).setOwnerDocument(var1);
         }
      }

   }

   void setPrintInfo(String var1, String var2, String var3) {
      this.publicId = var1;
      this.systemId = var2;
      this.internalSubset = var3;
   }

   void setReadonly() {
      this.entities.readonly = true;
      this.notations.readonly = true;
   }

   public void writeXml(XmlWriteContext var1) throws IOException {
      Writer var2 = var1.getWriter();
      Element var3 = ((NodeBase)this).getOwnerDocument().getDocumentElement();
      var2.write("<!DOCTYPE ");
      var2.write(var3 == null ? "UNKNOWN-ROOT" : var3.getNodeName());
      if (this.systemId != null) {
         if (this.publicId != null) {
            var2.write(" PUBLIC '");
            var2.write(this.publicId);
            var2.write("' '");
         } else {
            var2.write(" SYSTEM '");
         }

         var2.write(this.systemId);
         var2.write("'");
      }

      if (this.internalSubset != null) {
         var2.write(XmlDocument.eol);
         var2.write("[");
         var2.write(this.internalSubset);
         var2.write("]");
      }

      var2.write(">");
      var2.write(XmlDocument.eol);
   }
}
